# AR regressions for the sanctions intensity index ----------------------------

#  AR(1)
reg.ar1 <- lm(s ~ lag(s,1), subset(master, date>="1988Q4") )
summary(reg.ar1)

#  AR(2)
reg.ar2 <- lm(s ~ lag(s,1) + lag(s,2), subset(master, date>="1988Q3") )
summary(reg.ar2)

# Export results
stargazer(reg.ar1, reg.ar2, title = "Quarterly estimates of the sanctions intensity variable AR(1) and AR(2) models over the period 1989q1-2020q3", 
          covariate.labels = c("$s_{t-1}$","$s_{t-2}$"), 
          omit.table.layout = "n", df = FALSE,
          omit.stat = c("n", "LL", "f","rsq"), 
          no.space = TRUE, dep.var.caption = c("$s_{t}$"), 
          dep.var.labels.include = FALSE, 
          type = "text",
          out = "../LP Sanctions Iran Results/AR estimates/ar_table_s.tex")

rm (reg.ar1, reg.ar2)



# AR regressions for the global output growth ---------------------------------

#  AR(1)
reg.ar1 <- lm(d$lyw ~ lag(d$lyw,1), subset(master, date>="1988Q4") )
summary(reg.ar1)

#  AR(2)
reg.ar2 <- lm(d$lyw ~ lag(d$lyw,1) + lag(d$lyw,2), subset(master, date>="1988Q3") )
summary(reg.ar2)

# Export results
stargazer(reg.ar1, reg.ar2, title = "Quarterly estimates of the world real output growth AR(1) and AR(2) models over the period 1989q1-2020q1", 
          covariate.labels = c("$\\Delta \\bar{y}_{w,t-1}$", "$ \\Delta \\bar{y}_{w,t-2}$"), 
          omit.table.layout = "n", 
          df = FALSE,
          align = TRUE,
          omit.stat = c("n", "LL", "f","rsq"), 
          no.space = TRUE, 
          dep.var.caption = c("$ \\Delta \\bar{y}_{w,t}$"),
          dep.var.labels.include = FALSE, 
          type = "text",
          out = "../LP Sanctions Iran Results/AR estimates/ar_table_yw.tex")

rm (reg.ar1, reg.ar2)