% Code to generate the Table 1 of descriptive statistics of the paper by
% Laudati, Dario and M. Hashem Pesaran (2021). Identifying the Effects of
% Sanctions on the Iranian Economy Using Newspaper Coverage. CESifo WP9217

clear 
clc

%Load data from the "LP Sanctions Iran Data" folder
master_table = readtable('data_master_quarterly.xlsx');

% Generate sanctions intensity variable and annualized rates of change
master_table.s = master_table.san_on - 0.4*master_table.san_off;
master_table.dfx_free = 400*(log(master_table.fx_free) - lagmatrix(log(master_table.fx_free),1));
master_table.dfx_off = 400*(log(master_table.fx_off) - lagmatrix(log(master_table.fx_off),1));
master_table.dp = 400*(log(master_table.cpi) - lagmatrix(log(master_table.cpi),1));
master_table.dy_irn = 400*(log(master_table.y_irn) - lagmatrix(log(master_table.y_irn),1));

%Revolution and Iran-Iraq period (1979q3–1989q2)
rev_war = master_table(2:41,{'dfx_free', 'dfx_off', 'dp', 'dy_irn', 's'});
mean_rev_war = grpstats(rev_war);
median_s_rev_war = array2table(median(rev_war.s), 'VariableNames', {'median s'});
period_rev_war = table("Revolution and Iran-Iraq period (1979q3–1989q2)", 'VariableNames', {'Time period'});
table_rev_war = [period_rev_war mean_rev_war(:,2:end) median_s_rev_war]

%Rafsanjani presidency period (1989q3–1997q2)
pres89_97 = master_table(42:73,{'dfx_free', 'dfx_off', 'dp', 'dy_irn', 's'});
mean_pres89_97 = grpstats(pres89_97);
median_s_pres89_97 = array2table(median(pres89_97.s), 'VariableNames', {'median s'});
period_pres89_97 = table("Rafsanjani presidency period (1989q3–1997q2)", 'VariableNames', {'Time period'});
table_pres89_97 = [period_pres89_97 mean_pres89_97(:,2:end) median_s_pres89_97 ]

%Khatami presidency period (1997q3–2005q2)
pres97_05 = master_table(74:105,{'dfx_free', 'dfx_off', 'dp', 'dy_irn', 's'});
mean_pres97_05 = grpstats(pres97_05)
median_s_pres97_05 = array2table(median(pres97_05.s), 'VariableNames', {'median s'});
period_pres97_05 = table("Khatami presidency period (1997q3–2005q2)", 'VariableNames', {'Time period'});
table_pres97_05 = [period_pres97_05 mean_pres97_05(:,2:end) median_s_pres97_05]


%Ahmadinejad presidency period (2005q3–2013q2)
pres05_13 = master_table(106:137,{'dfx_free', 'dfx_off', 'dp', 'dy_irn', 's'});
mean_pres05_13 = grpstats(pres05_13)
median_s_pres05_13 = array2table(median(pres05_13.s), 'VariableNames', {'median s'});
period_pres05_13 = table("Ahmadinejad presidency period (2005q3–2013q2)", 'VariableNames', {'Time period'});
table_pres05_13 = [period_pres05_13 mean_pres05_13(:,2:end), median_s_pres05_13]

%Rouhani presidency period (2013q3–2021q2)
pres13_21 = master_table(138:end,{'dfx_free', 'dfx_off', 'dp', 'dy_irn', 's'});
mean_pres13_21 = grpstats(pres13_21)
median_s_pres13_21 = array2table(median(pres13_21.s(1:end-2)), 'VariableNames', {'median s'});
period_pres13_21 = table("Rouhani presidency period (2013q3–2021q2)", 'VariableNames', {'Time period'});
table_pres13_21 = [period_pres13_21 mean_pres13_21(:,2:end) median_s_pres13_21]

%Post-revolution full sample period (1979q3–2021q1)
post_rev =  master_table(2:end,{'dfx_free', 'dfx_off', 'dp', 'dy_irn', 's'});
mean_post_rev = grpstats(post_rev)
median_s_post_rev = array2table(median(post_rev.s(1:end-2)), 'VariableNames', {'median s'});
period_post_rev = table("Post-revolution full sample period (1979q3–2021q1)", 'VariableNames', {'Time period'});
table_post_rev = [period_post_rev mean_post_rev(:,2:end) median_s_post_rev]

%Post-War full sample period (1989q1–2021q1)
post_war = master_table(40:end,{'dfx_free', 'dfx_off', 'dp', 'dy_irn', 's'});
mean_post_war = grpstats(post_war)
median_s_post_war = array2table(median(post_war.s(1:end-2)), 'VariableNames', {'median s'});
period_post_war = table("Post-War full sample period (1989q1–2021q1)", 'VariableNames', {'Time period'});
table_post_war = [period_post_war mean_post_war(:,2:end) median_s_post_war]

filename = '../LP Sanctions Iran Results/descriptives/macroeconomic descriptives.xlsx';
writetable(table_rev_war, '../LP Sanctions Iran Results/descriptives/macroeconomic descriptives.xlsx', 'Sheet', 1, 'Range', 'A1:G2');
writetable(table_pres89_97, '../LP Sanctions Iran Results/descriptives/macroeconomic descriptives.xlsx', 'Sheet', 1, 'Range', 'A3:G3','WriteVariableNames',0 );
writetable(table_pres97_05, '../LP Sanctions Iran Results/descriptives/macroeconomic descriptives.xlsx', 'Sheet', 1, 'Range', 'A4:G4','WriteVariableNames',0 );
writetable(table_pres05_13, '../LP Sanctions Iran Results/descriptives/macroeconomic descriptives.xlsx', 'Sheet', 1, 'Range', 'A5:G5','WriteVariableNames',0 );
writetable(table_pres13_21, '../LP Sanctions Iran Results/descriptives/macroeconomic descriptives.xlsx', 'Sheet', 1, 'Range', 'A6:G6','WriteVariableNames',0 );
writetable(table_post_rev, '../LP Sanctions Iran Results/descriptives/macroeconomic descriptives.xlsx', 'Sheet', 1, 'Range', 'A7:G7','WriteVariableNames',0 );
writetable(table_post_war, '../LP Sanctions Iran Results/descriptives/macroeconomic descriptives.xlsx', 'Sheet', 1, 'Range', 'A8:G8','WriteVariableNames',0 );