# POPULATION ------------------------------------------------------------

# Total population statistics computed as sum of males and females subgroups
data$pop_5_9 <- data$m5_9 + data$f5_9
data$pop_10_14 <- data$m10_14 + data$f10_14
data$pop_15_19 <- data$m15_19 + data$f15_19


# EDUCATION ------------------------------------------------------------

# Total male and female population in schooling age
data$tot_male_st_age <- (data$m5_9 + data$m10_14 + data$m15_19)
data$tot_female_st_age <- (data$f5_9 + data$f10_14 + data$f15_19)

# Share of males and females students as a fraction of total schooling age pop.
data$sh_stud_m <- data$stud_m/data$tot_male_st_age
data$sh_stud_f <- data$stud_f/data$tot_female_st_age

# Students gender ratio
data$stud_gender_ratio <- data$sh_stud_f/data$sh_stud_m

# Total number of teachers
data$teach_tot <- data$teach_prim + data$teach_ls + data$teach_hs

# Number of teachers controlling for the 25-64 Iran population
data$teach_prim_ratio <- data$teach_prim/data$pop_25_64
data$teach_ls_ratio <- data$teach_ls/data$pop_25_64
data$teach_hs_ratio <- data$teach_hs/data$pop_25_64
data$teach_tot_ratio <- data$teach_tot/data$pop_25_64

# Total number of schools
data$school_tot <- data$sch_prim + data$sch_ls + data$sch_hs


# Rates of change
logchange_socio <- log(data.frame(data$sh_stud_m, 
                                  data$sh_stud_f, 
                                  data$school_tot, 
                                  data$sch_prim, 
                                  data$sch_ls,
                                  data$sch_hs, 
                                  data$teach_prim_ratio, 
                                  data$teach_ls_ratio,
                                  data$teach_hs_ratio, 
                                  data$teach_tot_ratio,
                                  data$stud_gender_ratio))


logchange_socio <- logchange_socio %>% rename(lsh_stud_m = data.sh_stud_m,
                                              lsh_stud_f = data.sh_stud_f,
                                              lschool_prim = data.sch_prim,
                                              lschool_ls = data.sch_ls,
                                              lschool_hs = data.sch_hs,
                                              lschool_tot = data.school_tot,
                                              lteach_prim = data.teach_prim_ratio,
                                              lteach_ls = data.teach_ls_ratio,
                                              lteach_hs = data.teach_hs_ratio,
                                              lteach_tot = data.teach_tot_ratio,
                                              lstud_gender = data.stud_gender_ratio)



aux3 <- data %>% mutate(de = logchange_socio - lag(logchange_socio))

