# Labor Outcomes -------------------------------------------------------------

# * Employment ----------------------------------------------------------


reg.rf1 <- lm(d_empl ~  s + lag(d_empl,1) + d$ly , subset(master, year>=1994))

reg.rf2 <- lm(d_empl ~  s + lag(d_empl,1) + d$ly + d$lp_oil, subset(master, year>=1994))


reg.rf3 <- lm(d_empl ~  s + lag(d_empl,1) + d$ly + d$lp_oil + d$lyw, subset(master, year>=1994))


reg.rf4 <- lm(d_empl ~  s + lag(d_empl,1) + d$ly + d$lp_oil + d$lyw  + d$lyoil, subset(master, year>=1994))


reg.rf5 <- lm(d_empl ~  s + lag(d_empl,1) + d$ly + d$lp_oil + d$lyw + d$lyoil + d$ly_tur, subset(master, year>=1994))


stargazer(reg.rf1, reg.rf2, reg.rf3, reg.rf4, reg.rf5,  
          title = "Effects of sanctions on the rate of change of employment rate in Iran relative to other MENA
          countries estimated over the period 1995-2019",
          covariate.labels = c("$s_{t}$",
                               "$\\Delta \\tilde{e}_{t-1}$",
                               "$\\Delta y_{t}$", 
                               "$\\Delta p^{0}_{t}$", 
                               "$\\Delta \\bar{y}_{w,t}$", 
                               "$\\Delta \\bar{y}^{0}_{t}$", 
                               "$\\Delta y^{Tur}_{t}$"), 
          omit = c("Constant"), 
          font.size = "small", 
          omit.table.layout = "n", 
          column.sep.width = "-10pt",
          omit.stat = c("n", "LL","ser", "f", "rsq"),
          no.space = TRUE, 
          dep.var.caption = c("$\\Delta \\tilde{e}_{t}$"), 
          dep.var.labels.include = FALSE, 
          align = TRUE,
          type = "text",
          out = '../LP Sanctions Iran Results/labor outcomes/employment.tex')

rm(list = ls(pattern = "^reg."))






# * Male Labor Force ----------------------------------------------------------

reg.rf1 <- lm(d_lf_diff_m ~  s + lag(d_lf_diff_m,1) + d$ly, subset(master, year>=1994))

reg.rf2 <- lm(d_lf_diff_m ~  s + lag(d_lf_diff_m,1) + d$ly + d$lp_oil, subset(master, year>=1994))

reg.rf3 <- lm(d_lf_diff_m ~  s + lag(d_lf_diff_m,1) + d$ly  + d$lp_oil + d$lyw, subset(master, year>=1994))

reg.rf4 <- lm(d_lf_diff_m ~  s + lag(d_lf_diff_m,1) + d$ly + d$lp_oil + d$lyw + d$lyoil, 
              subset(master, year>=1994))

reg.rf5 <- lm(d_lf_diff_m ~  s + lag(d_lf_diff_m,1) + d$ly + d$lp_oil + d$lyw + d$lyoil + d$ly_tur, 
              subset(master, year>=1994))

summary(reg.rf5)
stargazer(reg.rf1, reg.rf2, reg.rf3, reg.rf4, reg.rf5,   
          title = "Effects of sanctions on the rate of change of male labor force participation in Iran relative to
other MENA countries estimated over the period 1995-2019",  
          covariate.labels = c("$s_{t}$",
                               "$\\Delta \\widetilde{lf}_{m, t-1}$",
                               "$\\Delta y_{t}$", 
                               "$\\Delta p^{0}_{t}$", 
                               "$\\Delta \\bar{y}_{w,t}$", 
                               "$\\Delta \\bar{y}^{0}_{t}$", 
                               "$\\Delta y^{Tur}_{t}$"), 
          omit =c("Constant"),
          font.size = "small", 
          omit.table.layout = "n", 
          column.sep.width = "-10pt",
          omit.stat = c("n", "LL", "ser", "f", "rsq"),
          no.space = TRUE, 
          dep.var.caption = c("$\\Delta \\widetilde{lf}_{mt}$"),
          dep.var.labels.include = FALSE, 
          align = TRUE,
          type = "text",
          out = '../LP Sanctions Iran Results/labor outcomes/labor_force_males.tex')

rm(list = ls(pattern = "^reg."))




# * Female Labor Force ----------------------------------------------------------

reg.rf1 <- lm(d_lf_diff_w ~  s + lag(d_lf_diff_w,1)  + d$ly, subset(master, year>=1994))

reg.rf2 <- lm(d_lf_diff_w ~  s + lag(d_lf_diff_w,1) + d$ly + d$lp_oil, subset(master, year>=1994))

reg.rf3 <- lm(d_lf_diff_w ~  s + lag(d_lf_diff_w,1) + d$ly  + d$lp_oil + d$lyw, subset(master, year>=1994))

reg.rf4 <- lm(d_lf_diff_w ~  s + lag(d_lf_diff_w,1) + d$ly + d$lp_oil + d$lyw + d$lyoil, subset(master, year>=1994))

reg.rf5 <- lm(d_lf_diff_w ~  s + lag(d_lf_diff_w,1) + d$ly + d$lp_oil + d$lyw + d$lyoil + d$ly_tur, subset(master, year>=1994))


stargazer(reg.rf1, reg.rf2, reg.rf3, reg.rf4, reg.rf5,  
          title = "Effects of sanctions on the rate of change of female labor force participation in Iran relative
          to other MENA countries estimated over the period 1995-2019",
          covariate.labels = c("$s_{t}$",
                               "$\\Delta \\widetilde{lf}_{f, t-1}$",
                               "$\\Delta y_{t}$",
                               "$\\Delta p^{0}_{t}$", 
                               "$\\Delta \\bar{y}_{w,t}$",
                               "$\\Delta \\bar{y}^{0}_{t}$", 
                               "$\\Delta y^{Tur}_{t}$"), 
          omit =c("Constant"), 
          font.size = "small", 
          omit.table.layout = "n", 
          column.sep.width = "-10pt",
          omit.stat = c("n", "LL","ser", "f", "rsq"),
          no.space = TRUE, 
          dep.var.caption = c("$\\Delta \\widetilde{lf}_{ft}$"), 
          dep.var.labels.include = FALSE, 
          align = TRUE,
          type = "text",
          out = '../LP Sanctions Iran Results/labor outcomes/labor_force_females.tex')

rm(list = ls(pattern = "^reg."))



# * Total Labor Force ----------------------------------------------------------

reg.rf1 <- lm(d_lf_diff ~  s + lag(d_lf_diff,1)  + d$ly, subset(master, year>=1994))

reg.rf2 <- lm(d_lf_diff ~  s + lag(d_lf_diff,1) + d$ly + d$lp_oil, subset(master, year>=1994))

reg.rf3 <- lm(d_lf_diff ~  s + lag(d_lf_diff,1) + d$ly  + d$lp_oil + d$lyw, subset(master, year>=1994))

reg.rf4 <- lm(d_lf_diff ~  s + lag(d_lf_diff,1) + d$ly + d$lp_oil + d$lyw + d$lyoil , subset(master, year>=1994))

reg.rf5 <- lm(d_lf_diff ~  s + lag(d_lf_diff,1) + d$ly + d$lp_oil + d$lyw + d$lyoil + d$ly_tur, subset(master, year>=1994))

stargazer(reg.rf1, reg.rf2, reg.rf3, reg.rf4, reg.rf5,
          title = "Effects of sanctions on the rate of change of labor force participation in Iran relative to other
                  MENA countries estimated over the period 1995-2019",
          covariate.labels = c("$s_{t}$",
                               "$\\Delta \\widetilde{lf}_{t-1}$",
                               "$\\Delta y_{t}$",
                               "$\\Delta p^{0}_{t}$", 
                               "$\\Delta \\bar{y}_{w,t}$",
                               "$\\Delta \\bar{y}^{0}_{t}$", 
                               "$\\Delta y^{Tur}_{t}$"), 
          omit = c("Constant"), 
          font.size = "small", 
          omit.table.layout = "n", 
          column.sep.width = "-10pt",
          omit.stat = c("n", "LL","ser", "f","rsq"),
          no.space = TRUE, 
          dep.var.caption = c("$\\Delta \\widetilde{lf}_{t}$"), 
          dep.var.labels.include = FALSE, 
          align = TRUE,
          type = "text",
          out = '../LP Sanctions Iran Results/labor outcomes/labor_force_total.tex')

rm(list = ls(pattern = "^reg."))