# Master code to generate the quarterly descriptive statistics and estimates of the paper by 
# Laudati, Dario and M. Hashem Pesaran (2021) "Identifying the Effects of Sanctions
# on the Iranian Economy Using Newspaper Coverage", CESifo WP No. 9217


rm(list = ls())

# Set relative working directory
setwd("../LP Sanctions Iran Data")

#Loading packages
library(broom)
library(car)
library(caTools)
library(plyr)
library(dplyr)
library(expss)
library(Hmisc)
library(knitr)
library(lmtest)
library(lubridate)
library(MASS)
library(moments)
library(multcomp)
library(nnet)
library(pastecs)
library(psych)
library(psychTools)
library(readxl)
library(rstudioapi)
library(stargazer)
library(summarytools)
library(survival)
library(TSstudio)
library(xlsx)
library(xtable)
library(zoo)


# Data management ---------------------------------------------------------
# Importing data from current directory

data <- read_excel("data_master_quarterly.xlsx", sheet = "main")

data <- data %>% rename(y = y_irn)

# Declare time format
yq(data$date)

# Specify variables to be taken in first differences of logs
logchange <- log(data.frame(data$y, 
                            data$y_oil, 
                            data$y_tur, 
                            data$yw, 
                            data$cpi, 
                            data$fx_free, 
                            data$poil, 
                            data$gep,
                            data$geq,
                            data$m1,
                            data$m2,
                            data$qm))

logchange <- logchange %>% rename(ly = data.y, 
                                  lyoil = data.y_oil,
                                  ly_tur = data.y_tur, 
                                  lyw = data.yw,
                                  lp = data.cpi, 
                                  lfx = data.fx_free,
                                  lgep = data.gep, lgeq = data.geq,
                                  lp_oil = data.poil,
                                  lm1 = data.m1,
                                  lm2 = data.m2,
                                  lqm = data.qm)


aux1 <- data %>% mutate(dglr = glr - lag(glr))          #long run interest rates to be taken in first difference
aux2 <- data %>% mutate(d = logchange - lag(logchange)) #compute rates of change
master <- cbind(aux1, aux2)
master$date = as.yearqtr(master$date)                   #function to allow R to read dates in quarters
# master$s <- master$san_on - 0.4*master$san_off        #Implicit computation of sanction indicator variable
rm(data, logchange, aux1, aux2)


## Sanction indicator - descriptive statistics ----------------------------------
    source("../LP Sanctions Iran Codes/Q_s(t)_descriptives.R")
    
## AR regressions ---------------------------------------------------------------
    source("../LP Sanctions Iran Codes/Q_ar_regressions.R")

## SVAR model -------------------------------------------------------------------
    # Main model. Preferred ordering
    source("../LP Sanctions Iran Codes/Q_svar.R")
    
    # Robustness checks. Alternative possible orderings
    source("../LP Sanctions Iran Codes/Q_svar - other orderings.R")

## Single Equation results  -----------------------------------------------------
    source("../LP Sanctions Iran Codes/Q_single_equations.R")
    