# Master code to generate the yearly descriptive statistics and estimates of the paper by 
# Laudati, Dario and M. Hashem Pesaran (2021) "Identifying the Effects of Sanctions
# on the Iranian Economy Using Newspaper Coverage", CESifo WP No. 9217

rm(list = ls())

# Set relative working directory
setwd("../LP Sanctions Iran Data")

# Loading packages
library(broom)
library(car)
library(caTools)
library(plyr)
library(dplyr)
library(expss)
library(Hmisc)
library(knitr)
library(lmtest)
library(lubridate)
library(MASS)
library(moments)
library(multcomp)
library(nnet)
library(pastecs)
library(psych)
library(psychTools)
library(readxl)
library(rstudioapi)
library(stargazer)
library(summarytools)
library(survival)
library(TSstudio)
library(xlsx)
library(xtable)
library(zoo)

# Data management ---------------------------------------------------------
# Importing data from current directory
data <- read_excel("data_master_yearly.xlsx", 
                   sheet = "main")

data <- data %>% rename(y = y_irn)


# Specify variables to be taken in first difference of logs
logchange_econ <- log(data.frame(data$y, 
                                 data$y_oil, 
                                 data$y_tur, 
                                 data$yw, 
                                 data$poil,
                                 data$cpi, 
                                 data$fx_free, 
                                 data$gep, 
                                 data$geq,
                                 data$lf,
                                 data$lf_mena,
                                 data$lf_w, 
                                 data$lf_w_mena, 
                                 data$lf_m, 
                                 data$lf_m_mena,
                                 data$emp,
                                 data$emp_mena))
                                 

logchange_econ <- logchange_econ %>% rename(ly = data.y, 
                                  lyoil = data.y_oil,
                                  ly_tur = data.y_tur, 
                                  lyw = data.yw,
                                  lp = data.cpi, 
                                  lfx = data.fx_free,
                                  lgep = data.gep, 
                                  lgeq = data.geq,
                                  lp_oil = data.poil,
                                  lLF_iran = data.lf,
                                  lLF_mena = data.lf_mena,
                                  lLF_w = data.lf_w,
                                  lLF_w_mena = data.lf_w_mena,
                                  lLF_m = data.lf_m,
                                  lLF_m_mena = data.lf_m_mena,
                                  lempl_iran = data.emp,
                                  lempl_mena = data.emp_mena
                                  )


aux <- data %>% mutate(dglr = glr - lag(glr))
aux2 <- data %>% mutate(d = logchange_econ - lag(logchange_econ))


# Call a subroutine where population and education variables are generated -----
  source("../LP Sanctions Iran Codes/Y_construct_sociodemographic_vars.R")


master <- cbind(aux, aux2, aux3)

# Labor statistics to be considered as difference from their MENA region average
master$d_empl <- master$d$lempl_iran - master$d$lempl_mena
master$d_lf_diff <- master$d$lLF_iran - master$d$lLF_mena
master$d_lf_diff_m <- master$d$lLF_m - master$d$lLF_m_mena
master$d_lf_diff_w <- master$d$lLF_w - master$d$lLF_w_mena

#sanctions indicator variable
master$s <- master$san_on - 0.4*master$san_off

rm(data, logchange_econ, logchange_socio, aux, aux2, aux3)



## Socio-demographic results  --------------------------------------------------

    # * Labor ------------------------------------------------------------------
    source("../LP Sanctions Iran Codes/Y_labor_outcomes.R")


    # * Education  -------------------------------------------------------------
    source("../LP Sanctions Iran Codes/Y_education_outcomes.R")
